# Changelog

<!--next-version-placeholder-->

<!-- ## v0.2.0 (10/09/2021)

### Feature

- Added new datasets modules to load example data

### Fix

- Check type of argument passed to `plotting.plot_words()`

### Tests

- Added new tests to all package modules in test_pycounts.py -->

## v0.1.1 (14/02/2024)
- #12 correct installation guide in README.md and cleanup

## v0.1.0 (10/01/2024)

- First release of `ZnaKes`
